==> V00.42.zip: tweet_live-V00.42/web/client_live.php <==
<?php

/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
include_once './common.php';

/**
 * Do we already have a valid Access Token or need to go get one?
 */
if (!isset($_SESSION['TWITTER_ACCESS_TOKEN']) && isset($_GET['CONNECT']) ) {
    /**
     * Guess we need to go get one!
     */
    $token = $consumer->getRequestToken();
    $_SESSION['TWITTER_REQUEST_TOKEN'] = serialize($token);

    /**
     * Now redirect user to Twitter site so they can log in and
     * approve our access
     */
    $consumer->redirect();
}

/* CLIENT VAR LIVE */

$C_hashtag= "#rsln";
$C_link  = "http://www.rslnmag.fr/blog/2011/3/24/la-journaliste-mercedes-bunz-prochaine-invitee-des-rencontres-rsln/";
$C_title = "Mercedes Bunz et le journaliste";
$C_REP   = "rsln-mercedes-bunz/";
$C_description  = "Elle nous racontera comment les algorithmes ont fini par devenir des producteurs d'infos et pourquoi ils ne remplaceront pour autant jamais les journalistes.
<br/><br/>
(titre de sa conférence, en VO : When robots learned to write, How the rise of the algorithms will change journalism and revolutionize our concept of knowledge.)
<br/><br/>
C'est un thème sur lequel elle avait été très remarquée, lors d'une intervention à la conférence Lift, à Genève, en mai 2010.";

$C_partenaires  = "
		 <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
 IRI </a>
		 |  <a href='http://www.rslnmag.fr/' class='footerLink' target='_blank' > RSLN  </a>
		 |  <a href='http://www.microsoft.fr/' class='footerLink' target='_blank'> MICROSOFT.fr  </a>";

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">

<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>RSLN  - Live Video and Annotation</title>
	<meta http-equiv="X-UA-Compatible" content="IE=8" /> 

    <!-- Framework CSS -->
    <link rel="stylesheet" href="res/blueprint/screen.css" type="text/css" media="screen, projection">
    <link rel="stylesheet" href="res/blueprint/print.css" type="text/css" media="print">
    <!--[if lt IE 8]><link rel="stylesheet" href="blueprint/ie.css" type="text/css" media="screen, projection"><![endif]-->
	<link rel="stylesheet" href="res/blueprint/plugins/fancy-type/screen.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/custom.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" type="text/css" href="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.css" media="screen">
	<link rel="stylesheet" type="text/css" href="res/niceforms/niceforms-custom.css" media="screen" >

	<!-- JAVASCRIPT --> 
	<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
	<script type="text/javascript" src="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.pack.js"></script>
	<script type="text/javascript" src="res/metadataplayer/res/js/jquery.tools.min.js"></script>
	<script type="text/javascript" src="res/niceforms/niceforms.js"></script>
	<script src="http://widgets.twimg.com/j/2/widget.js"></script>
	
	<!-- FONT -->
	<link href='http://fonts.googleapis.com/css?family=PT+Sans+Narrow&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=PT+Sans&subset=latin' rel='stylesheet' type='text/css'>
	<link href='http://fonts.googleapis.com/css?family=Geo&subset=latin' rel='stylesheet' type='text/css'>

	<script type="text/javascript">	
	$(document).ready(function() {

			doTimer();
			//$("txt").hide();
			$(".loginbutton").click(function() {
				document.location.href="<?php URL_ROOT ?>?CONNECT=true";
			});
			$("#IDENTIFIER").click(function() {
				document.location.href="<?php URL_ROOT ?>?CONNECT=true";
			});
			
			$("#messageSuccess").hide();
			$("#messageFailed").hide();
			$("#txt").hide();
			
			// BUTTONS
			$("#positive").click(function(){
				var MyValue = $('#status').attr("value");
				 $('#status').attr("value",MyValue+"++ ");
			});
			$("#negative").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"-- ");
			});
			$("#reference").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"== ");
			});
			$("#question").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"?? ");
			});
			
			// SEND TWEETS 
			$("#sendTweet").click(function(){
				var MyStatus = $('#status').attr("value");
				$.post('tweet_ajax.php', {status:MyStatus}
				,function(data) {
				
					if(data=="true"){
						$("#messageSuccess").show('fast');
						$("#messageSuccess").delay(800).hide('slow');
						$('#status').attr("value","#rsln");
					}else{
						$("#error").text(data);
						$("#messageFailed").show('fast');
						$("#messageFailed").delay(800).hide('slow');
					}
					
				});
				
			});			
			
			$(".timeFrame").tooltip();
			/*
			*   Lightbox button 
			*/
			$("#About").fancybox({
				'titlePosition'		: 'inside',
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'enableEscapeButton': 'none',
				'margin' 			: 1,
				'padding' 			: 0
			}<?php if (!isset($_SESSION['TWITTER_ACCESS_TOKEN'])){echo(").trigger('click');");}else{echo(");");} ?>
			
			
			$("#Program").fancybox({
				'width'				: '75%',
				'height'			: '75%',
				'autoScale'			: false,
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'type'				: 'iframe'
			});

			$("#Video_ldt").fancybox({
				'width'				: 1021,
				'height'			: 661,
				'autoScale'			: false,
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'type'				: 'iframe'
			});
			
			$("#ACCES").click(function() {
				$.fancybox.close();
			});
			
			// Buttons 
			
		
		});
		
		
		<!-- LIMIT TEXTAREA:
		function imposemax(Object)
		{
		  return (Object.value.length <= 140);
		}
		// End -->
		
		<!-- TIMER 
		var c=0;
		var t;
		var timer_is_on=0;

		function timedCount()
		{
			document.getElementById('txt').value=c;
			c = c+1;
			t = window.setTimeout("timedCount()",1000);
			$(".twtr-ft").hide();
			$(".twtr-hd").hide();
			//twtr-tweet
			$(".twtr-tweet").each(colorTweetings);
		
		}

		function colorTweetings (){
				var tweettemp = $(this).html();
				if (tweettemp.search(/\x3F\x3F/)!=-1){
					 $(this).css({'background-color': '#bfdbec','color':"#000"});
				}
				if (tweettemp.search(/\x2B\x2B/)!=-1){
					 $(this).css({'background-color': '#c5e7cd','color':"#fff"});
				}
				if (tweettemp.search(/\x2D\x2D/)!=-1){
					 $(this).css({'background-color': '#f6ced0','color':"#fff"});
				}
				if (tweettemp.search(/\x3D\x3D/)!=-1){
					 $(this).css({'background-color': '#ecedc1','color':"#000"});
				}
		};
			

		
		function doTimer()
		{
		if (!timer_is_on)
		  {
		  timer_is_on=1;
		  timedCount();
		  }
		}

		function stopCount()
		{
			clearTimeout(t);
			timer_is_on=0;
		}
		//
		//-->
	</script>
	
	<script type="text/javascript">
	
	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-9955524-3']);
	  _gaq.push(['_setDomainName', '.iri.centrepompidou.fr']);
	  _gaq.push(['_trackPageview']);
	
	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();
	
	</script>
	
  </head>
  <body>
    <div class="container">
      <img src="<?php echo($C_REP); ?>/images/head_logo.gif" class="Producteur logo">
		<div id="minilogo" style="margin-left:85px;height:5px;top:5px;"></div>
	  <ul class="menu"> 
	  <li class="menuUnderline"><a href="index.php" class="menuLink">
	  	<?php print $translate->_("Accueil"); ?> </a></li>
	  <li class="menuUnderline" ><a href="<?php echo($C_link); ?>" class="menuLink" target="_blank" id='Program'> 
	  	<?php print $translate->_("Programme"); ?></a></li>
	  <li ><a href="about.php" class="menuLink" >
	  	<?php print $translate->_("A propos"); ?></a></li>

	  </ul>
	  
	  	  <ul class="menu" > 
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php URL_ROOT ?>?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>

	  
	  <div class="videoLive">
		<div class="videoLivePlayer">
			<!--img src="<?php echo($C_REP); ?>/images/big_visuel_rsln_mb.jpg" width="500"  height="375" /-->
			<object id="player" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" name="player" width="500" height="375"> 
				<param name="movie" value="res/mediaplayer/player.swf" /> 
				<param name="allowfullscreen" value="true" /> 
				<param name="allowscriptaccess" value="always" /> 
				<param name="wmode" value="transparent" />
				<param name="flashvars" value="autostart=true&live=true&image=images/bgd_player.jpg&provider=rtmp&streamer=rtmp://media.iri.centrepompidou.fr/ddc_player/&file=livestream&controlbar=none&autostart=true" /> 
				<embed 
					type="application/x-shockwave-flash"
					id="player2"
					name="player2"
					src="res/mediaplayer/player.swf" 
					width="500" 
					height="375"
					allowscriptaccess="always" 
					allowfullscreen="true"
					wmode="transparent"
					flashvars="autostart=true&live=true&provider=rtmp&streamer=rtmp://media.iri.centrepompidou.fr/ddc_player/&file=livestream&image=images/bgd_player.jpg&controlbar=none&autostart=true" 
					
				/> 
			</object> 
			
		</div>	
		
	  </div>

	<div class="videoLiveProgram">	
		
		<div class="arrowContainer">
			<div class="arrow"> </div>
		</div>
		<div class="videoLiveProgramTitle">
			<b><?php echo($C_title); ?></b></div>
		<div class="videoLiveProgramDescription">
			<br><?php echo($C_description); ?></div>
		
		
	</div>
	  
	  <div class="tweetWriter">
		<h3 class="tweetWriterTitle"><?php print $translate->_("ClientTitle1 :"); ?></h3>
		<form  action="tweet.php" method="post" id="statusform" >
		<?php if (!isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
				echo("<div class='loginbutton' ><a href='".URL_ROOT."?CONNECT=true' class='loginlink'>
				".$translate->_("Vous n'êtes pas connecté.")."</a></div>");
			  }else{
				echo("<textarea name='status' id='status' rows='3' cols='50' onkeypress='return imposemax(this);'>".$C_hashtag."</textarea>");
			  }
		?>


				<div id="messageSuccess" style="background-color:lightgreen;">
					<?php print $translate->_("Envoyé"); ?><br><br>
				</div>
				
				<div id="messageFailed" style="background-color:red;">
					<?php print $translate->_("Erreur1"); ?><div id="error">&nbsp;</div><br/><br>
				</div>

			  
			
			<a class="button_w" href="#"  id="sendTweet" style="float:right;margin-right:15px;margin-left:35px;width:70px;" >
			<span><?php print $translate->_("Envoyer"); ?></span></a> 
			<!--<button name="s" type="button" id="sendTweet"
					style="float:right;margin-right:15px;margin-left:35px;width:70px;"  >Envoyer</button>-->
			<a 
					
					id="positive"
					title="accord"
					class="tweetButton">++</a>
			<a 
					
					id="negative"
					title="désaccord"
					class="tweetButton">--</a>
			<a
					
					id="reference"
					title="reference"
					class="tweetButton">==</a>
			<a 
					
					id="question"  
					title="question"
					class="tweetButton"> ??</a>
		</form>
	  </div>
	  
	  <div class="tweetReader">
			<script>
				new TWTR.Widget({
				  version: 2,
				  type: 'search',
				  search: '<?php echo($C_hashtag); ?>',
				  interval: 1000,
				  title: '',
				  subject: '',
				  width: 377,
				  height: 450,
				  theme: {
					shell: {
					  background: '#ffffff',
					  color: '#ffffff'
					},
					tweets: {
					  background: '#ffffff',
					  color: '#444444',
					  links: '#1985b5'
					}
				  },
				  features: {
					scrollbar: false,
					loop: true,
					live: true,
					hashtags: true,
					timestamp: true,
					avatars: true,
					toptweets: true,
					behavior: 'default'
				  }
				}).render().start();
			</script>
	  </div>

      <div class="footer">
		<hr>
		 <?php 
				echo($C_partenaires);
				
				if (isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>".$translate->_("D&eacute;connexion")."</a>");
				}
		 ?>
		  <input type="text" id="txt" size="3"/>
		  
	  </div>   
	

    </div>
	
	<!-- LIGHTBOX --> 
	<div style="display:none;">
		<div id="Aboutbox" >
		<div class="lightBorder">
			<div class="lightTitle" style="height:45px;">&nbsp;  </div>
			<div class="lightSubTitle"><?php print $translate->_("splatchPageTitle"); ?></div>
			<div class="lightDescription"><?php print $translate->_("splatchPageText"); ?></div>
			<div>
				<br/>
				<a class="button_b" href="#"  id="IDENTIFIER"><span><?php print $translate->_("S&apos;identifier"); ?></span></a> <br/><br/>
				<a class="button_w" href="#"  id="ACCES"><span><?php print $translate->_("Libre accès"); ?></span></a> 
			</div>
		</div>
		</div>
	</div>
	<!-- END LIGHTBOX -->

	
  </body>
</html>

==> V00.73.zip: tweet_live-V00.73/web/client_live.php <==
<?php

/**
 * include some common code (like we did in the 90s)
 * People still do this? ;)
 */
include_once './common.php';

/**
 * Do we already have a valid Access Token or need to go get one?
 */
if (!isset($_SESSION['TWITTER_ACCESS_TOKEN']) && isset($_GET['CONNECT']) ) {
    /**
     * Guess we need to go get one!
     */
    $token = $consumer->getRequestToken();
    $_SESSION['TWITTER_REQUEST_TOKEN'] = serialize($token);

    /**
     * Now redirect user to Twitter site so they can log in and
     * approve our access
     */
    $consumer->redirect();
}

/* CLIENT VAR LIVE */

$C_hashtag= "#THD12";
$C_link  = "http://www.portailthd.fr/";
$C_title = "Bilan du projet Plateforme THD";
$C_REP   = "thd/";
$C_description  = "12 mai 2011<br/>
Centre Pompidou<br/>
<br/>
Les acteurs de la plateforme THD et les organismes qui ont soutenu le projet se retrouvent le 12 mai 2011 pour faire le bilan de trois années d’actions prospectives et d’études d’usages autour de plus de 30 expérimentations de nouveaux services.
";

$C_partenaires  = "
		 <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
 IRI </a>
		 |  <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
		 |  <a href='http://www.portailthd.fr/' class='footerLink' target='_blank'>Portail THD</a>";

?>

<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">

<html lang="<?php echo($actual); ?>">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>Bilan du projet Plateforme THD</title>
	<meta http-equiv="X-UA-Compatible" content="IE=8" /> 

    <!-- Framework CSS -->
    <link rel="stylesheet" href="res/blueprint/screen.css" type="text/css" media="screen, projection">
    <link rel="stylesheet" href="res/blueprint/print.css" type="text/css" media="print">
    <!--[if lt IE 8]><link rel="stylesheet" href="blueprint/ie.css" type="text/css" media="screen, projection"><![endif]-->
	<link rel="stylesheet" href="res/blueprint/plugins/fancy-type/screen.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" href="res/css/custom.css" type="text/css" media="screen, projection">
	<link rel="stylesheet" type="text/css" href="res/jquery.fancybox/fancybox/jquery.fancybox-1.3.4.css" media="screen">
	<link rel="stylesheet" type="text/css" href="res/niceforms/niceforms-custom.css" media="screen" >

	<!-- JAVASCRIPT --> 
	<script type="text/javascript" src="<?php echo(registry_url('jquery','js'))?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('fancybox','js'))?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('jquery-tools','js'))?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('niceforms','js'))?>"></script>
	<script type="text/javascript" src="<?php echo(registry_url('tw-widget','js'))?>"></script>
	
	<!-- FONT -->
	<link href='<?php echo(registry_url('PT-Sans_Narrow','font'))?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('PT-Sans','font'))?>' rel='stylesheet' type='text/css'>
	<link href='<?php echo(registry_url('Geo','font'))?>' rel='stylesheet' type='text/css'>

	<script type="text/javascript">	
	$(document).ready(function() {

			doTimer();
			//$("txt").hide();
			$(".loginbutton").click(function() {
				document.location.href="<?php URL_ROOT ?>client.php?CONNECT=true";
			});
			$("#IDENTIFIER").click(function() {
				document.location.href="<?php URL_ROOT ?>client.php?CONNECT=true";
			});
			
			$("#messageSuccess").hide();
			$("#messageFailed").hide();
			$("#txt").hide();
			
			// BUTTONS
			$("#positive").click(function(){
				var MyValue = $('#status').attr("value");
				 $('#status').attr("value",MyValue+"++ ");
			});
			$("#negative").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"-- ");
			});
			$("#reference").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"== ");
			});
			$("#question").click(function(){
				var MyValue = $('#status').attr("value");
				$('#status').attr("value",MyValue+"?? ");
			});
			
			// SEND TWEETS 
			$("#sendTweet").click(function(){
				var MyStatus = $('#status').attr("value");
				$.post('tweet_ajax.php', {status:MyStatus}
				,function(data) {
				
					if(data=="true"){
						$("#messageSuccess").show('fast');
						$("#messageSuccess").delay(800).hide('slow');
						$('#status').attr("value","#THD12");
					}else{
						$("#error").text(data);
						$("#messageFailed").show('fast');
						$("#messageFailed").delay(800).hide('slow');
					}
					
				});
				
			});			
			
			$(".timeFrame").tooltip();
			/*
			*   Lightbox button 
			*/
			$("#About").fancybox({
				'titlePosition'		: 'inside',
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'enableEscapeButton': 'none',
				'margin' 			: 1,
				'padding' 			: 0
			}<?php if (!isset($_SESSION['TWITTER_ACCESS_TOKEN'])){echo(").trigger('click');");}else{echo(");");} ?>
			
			
			$("#Program").fancybox({
				'width'				: '75%',
				'height'			: '75%',
				'autoScale'			: false,
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'type'				: 'iframe'
			});

			$("#Video_ldt").fancybox({
				'width'				: 1021,
				'height'			: 661,
				'autoScale'			: false,
				'transitionIn'		: 'none',
				'transitionOut'		: 'none',
				'type'				: 'iframe'
			});
			
			$("#ACCES").click(function() {
				$.fancybox.close();
			});
			
			// Buttons 
			
		
		});
		
		
		<!-- LIMIT TEXTAREA:
		function imposemax(Object)
		{
		  return (Object.value.length <= 140);
		}
		// End -->
		
		<!-- TIMER 
		var c=0;
		var t;
		var timer_is_on=0;

		function timedCount()
		{
			document.getElementById('txt').value=c;
			c = c+1;
			t = window.setTimeout("timedCount()",1000);
			$(".twtr-ft").hide();
			$(".twtr-hd").hide();
			//twtr-tweet
			$(".twtr-tweet").each(colorTweetings);
		
		}

		function colorTweetings (){
				var tweettemp = $(this).html();
				if (tweettemp.search(/\x3F\x3F/)!=-1){
					 $(this).css({'background-color': '#bfdbec','color':"#000"});
				}
				if (tweettemp.search(/\x2B\x2B/)!=-1){
					 $(this).css({'background-color': '#c5e7cd','color':"#fff"});
				}
				if (tweettemp.search(/\x2D\x2D/)!=-1){
					 $(this).css({'background-color': '#f6ced0','color':"#fff"});
				}
				if (tweettemp.search(/\x3D\x3D/)!=-1){
					 $(this).css({'background-color': '#ecedc1','color':"#000"});
				}
		};
			

		
		function doTimer()
		{
		if (!timer_is_on)
		  {
		  timer_is_on=1;
		  timedCount();
		  }
		}

		function stopCount()
		{
			clearTimeout(t);
			timer_is_on=0;
		}
		//
		//-->
	</script>
	
	<script type="text/javascript">
	
	  var _gaq = _gaq || [];
	  _gaq.push(['_setAccount', 'UA-23581291-1']);
	  _gaq.push(['_trackPageview']);
	
	  (function() {
	    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
	    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
	    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
	  })();
	
	</script>
	
  </head>
  <body>
    <div class="container">
      <img src="images/ENMI_2010_logo.gif" class="Producteur logo">
		<div id="minilogo" style="margin-left:85px;height:5px;top:5px;"></div>
	  <ul class="menu"> 
	  <li class="menuUnderline"><a href="index.php" class="menuLink">
	  	<?php print $translate->_("Accueil"); ?> </a></li>
	  <li class="menuUnderline" ><a href="<?php echo($C_link); ?>" class="menuLink" target="_blank" id='Program'> 
	  	<?php print $translate->_("Programme"); ?></a></li>
	  <li ><a href="about.php" class="menuLink" >
	  	<?php print $translate->_("A propos"); ?></a></li>

	  </ul>
	  
	  	  <ul class="menu" > 
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>client.php?lang=ja_JP" class="menuLink" >
	       <img src='images/flag_jp.gif'<?php if($actual!="ja_JP"){echo("style='opacity: .5;'"); } ?> />
	        <?php print $translate->_("Japonais"); ?></a></li>
	  <li class="menuUnderline"><a href="<?php URL_ROOT ?>client.php?lang=fr" class="menuLink">
	       <img src='images/flag_fr.gif' <?php if($actual!="fr"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Français"); ?></a></li>
	  <li ><a href="<?php URL_ROOT ?>client.php?lang=en" class="menuLink">
	       <img src='images/flag_en.gif' <?php if($actual!="en"){echo("style='opacity: .5;'"); } ?> />
	       <?php print $translate->_("Anglais"); ?></a></li>
	  </ul>

	  
	  <div class="videoLive">
		<div class="videoLivePlayer">
			<object id="player" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" name="player" width="500" height="375"> 
				<param name="movie" value="res/mediaplayer/player.swf" /> 
				<param name="allowfullscreen" value="true" /> 
				<param name="allowscriptaccess" value="always" /> 
				<param name="wmode" value="transparent" />
				<param name="flashvars" value="autostart=true&live=true&image=images/bgd_player_thd.png&provider=rtmp&streamer=rtmp://media.iri.centrepompidou.fr/ddc_player/&file=livestream&controlbar=none&autostart=true" /> 
				<embed 
					type="application/x-shockwave-flash"
					id="player2"
					name="player2"
					src="res/mediaplayer/player.swf" 
					width="500" 
					height="375"
					allowscriptaccess="always" 
					allowfullscreen="true"
					wmode="transparent"
					flashvars="autostart=true&live=true&provider=rtmp&streamer=rtmp://media.iri.centrepompidou.fr/ddc_player/&file=livestream&image=images/bgd_player_thd.png&controlbar=none&autostart=true" 
					
				/> 
			</object> 
			
		</div>	
		
	  </div>

	<div class="videoLiveProgram">	
		
		<div class="arrowContainer">
			<div class="arrow"> </div>
		</div>
		<div class="videoLiveProgramTitle">
			<b><?php echo($C_title); ?></b></div>
		<div class="videoLiveProgramDescription">
			<br><?php echo($C_description); ?></div>
		
		
	</div>
	  
	  <div class="tweetWriter">
		<h3 class="tweetWriterTitle"><?php print $translate->_("ClientTitle1 :"); ?></h3>
		<form  action="tweet.php" method="post" id="statusform" >
		<?php if (!isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
				echo("<div class='loginbutton' ><a href='".URL_ROOT."client.php?CONNECT=true' class='loginlink'>
				".$translate->_("Vous n'êtes pas connecté.")."</a></div>");
			  }else{
				echo("<textarea name='status' id='status' rows='3' cols='50' onkeypress='return imposemax(this);'>".$C_hashtag."</textarea>");
			  }
		?>


				<div id="messageSuccess" style="background-color:lightgreen;">
					<?php print $translate->_("Envoyé"); ?><br><br>
				</div>
				
				<div id="messageFailed" style="background-color:red;">
					<?php print $translate->_("Erreur1"); ?><div id="error">&nbsp;</div><br/><br>
				</div>

			  
			
			<a class="button_w" href="#"  id="sendTweet" style="float:right;margin-right:15px;margin-left:35px;width:70px;" >
			<span><?php print $translate->_("Envoyer"); ?></span></a> 
			<!--<button name="s" type="button" id="sendTweet"
					style="float:right;margin-right:15px;margin-left:35px;width:70px;"  >Envoyer</button>-->
			<a 
					
					id="positive"
					title="accord"
					class="tweetButton">++</a>
			<a 
					
					id="negative"
					title="désaccord"
					class="tweetButton">--</a>
			<a
					
					id="reference"
					title="reference"
					class="tweetButton">==</a>
			<a 
					
					id="question"  
					title="question"
					class="tweetButton"> ??</a>
		</form>
	  </div>
	  
	  <div class="tweetReader">
			<script>
				new TWTR.Widget({
				  version: 2,
				  type: 'search',
				  search: '<?php echo($C_hashtag); ?>',
				  interval: 1000,
				  title: '',
				  subject: '',
				  width: 377,
				  height: 450,
				  theme: {
					shell: {
					  background: '#ffffff',
					  color: '#ffffff'
					},
					tweets: {
					  background: '#ffffff',
					  color: '#444444',
					  links: '#1985b5'
					}
				  },
				  features: {
					scrollbar: false,
					loop: true,
					live: true,
					hashtags: true,
					timestamp: true,
					avatars: true,
					toptweets: true,
					behavior: 'default'
				  }
				}).render().start();
			</script>
	  </div>

      <div class="footer">
		<hr>
		 <?php 
				echo($C_partenaires);
				
				if (isset($_SESSION['TWITTER_ACCESS_TOKEN'])){
					echo("| 	<a href='clear.php'  class='footerLink'>".$translate->_("D&eacute;connexion")."</a>");
				}
		 ?>
		  <input type="text" id="txt" size="3"/>
		  
	  </div>   
	

    </div>
	
	<!-- LIGHTBOX --> 
	<div style="display:none;">
		<div id="Aboutbox" >
		<div class="lightBorder">
			<div class="lightTitle" style="height:45px;">&nbsp;  </div>
			<div class="lightSubTitle"><?php print $translate->_("splatchPageTitle"); ?></div>
			<div class="lightDescription"><?php print $translate->_("splatchPageText"); ?></div>
			<div>
				<br/>
				<a class="button_b" href="#"  id="IDENTIFIER"><span><?php print $translate->_("S&apos;identifier"); ?></span></a> <br/><br/>
				<a class="button_w" href="#"  id="ACCES"><span><?php print $translate->_("Libre accès"); ?></span></a> 
			</div>
		</div>
		</div>
	</div>
	<!-- END LIGHTBOX -->

	
  </body>
</html>
